#
# spec file for package iproute2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           iproute2
Version:        4.4
Release:        6.1
%define rversion 4.4.0
Summary:        Linux network configuration utilities
License:        GPL-2.0
Group:          Productivity/Networking/Routing
Url:            http://www.linuxfoundation.org/collaborate/workgroups/networking/iproute2
# Using GPL-2.0 instead of GPL-2.0+ because of tc_skbedit.h and tc/q_multiq.c

#DL-URL:	http://kernel.org/pub/linux/utils/net/iproute2/
#Git-Clone:	git://git.kernel.org/pub/scm/linux/kernel/git/shemminger/iproute2
Source:         http://kernel.org/pub/linux/utils/net/iproute2/%name-%rversion.tar.xz
Source2:        http://kernel.org/pub/linux/utils/net/iproute2/%name-%rversion.tar.sign
Source666:      pre_checkin.sh
Source667:      %name.keyring
Patch1:         adjust-installation-directories-for-SLE.patch
Patch2:         use-sysconf-_SC_CLK_TCK-if-HZ-undefined.patch
Patch3:         add-explicit-typecast-to-avoid-gcc-warning.patch
Patch4:         avoid-unused-return-value-gcc-warnings.patch
Patch5:         fix-build-with-D_FORTIFY_SOURCE-2.patch
Patch6:         xfrm-support-displaying-transformations-used-for-Mob.patch
Patch7:         man-fix-documentation-references-in-manual-pages.patch
Patch9:         routel-fix-infinite-loop-in-line-parser.patch
Patch10:        iproute-fix-documentation-for-ip-rule-scan-order.patch
Patch11:        iproute-fix-documentation-for-ip-rule-scan-order-2.patch
Patch12:        man-ip-rule.8-Further-clarify-how-to-interpret-prior.patch
Patch13:        man-ip-route.8-Mention-that-lower-metric-means-highe.patch
Patch14:        libnetlink-Double-the-dump-buffer-size.patch
Patch15:        iplink-check-for-message-truncation-in-iplink_get.patch
Patch16:        iplink-double-the-buffer-size-also-in-iplink_get.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  db-devel
BuildRequires:  flex
BuildRequires:  pkgconfig >= 0.21
BuildRequires:  xz
%define with_xt 1
%if 0%{?with_xt}
BuildRequires:  pkgconfig(libmnl)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(xtables) >= 1.4.11
%endif
Provides:       iproute = %version-%release
Provides:       %name(xfrm6_raw) = %version-%release

%description
iproute2 is a collection of user-space utilities to set up networking
under Linux from the command-line. It can inspect and configure,
among other things: interface paramters, IP addresses, routing,
tunnels, bridges, packet transformations (IPsec, etc.), and Quality
of Service.

%package -n libnetlink-devel
Summary:        A Higher Level Interface to the Netlink Service
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Provides:       libnetlink = %version-%release

%description -n libnetlink-devel
libnetlink provides a higher-level interface to rtnetlink(7).
New programs should use libmnl-devel instead.

%prep
%setup -qn %name-%rversion
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
find . -name *.orig -delete

%build
# build with -fPIC. For details see
# https://bugzilla.novell.com/show_bug.cgi?id=388021
xt_libdir="$(pkg-config xtables --variable=xtlibdir)";
xt_cflags="$(pkg-config xtables --cflags)";
make %{?_smp_mflags} LIBDIR="%_libdir" CCOPTS="-D_GNU_SOURCE %optflags -Wstrict-prototypes -Wno-error -fPIC -DXT_LIB_DIR=\\\"$xt_libdir\\\" $xt_cflags"

%install
b="%buildroot";
install -d "$b"/{etc/,sbin/,usr/{sbin,share/man/man{3,8}}}
install -d "$b"/{/usr/include,%_libdir,/usr/share}
make install DESTDIR="$b" LIBDIR="%_libdir" \
	MODDESTDIR="$b/%_libdir/tc" DOCDIR="%_docdir/%name";
# We have m_xt
rm -f "$b/%_libdir/tc/m_ipt.so";
install -pm0644 "lib/libnetlink.a" "$b/%_libdir/";
chmod -x "$b/%_libdir/libnetlink.a";
install -pm0644 "include/libnetlink.h" "$b/%_includedir/";
chmod -x "$b/%_includedir/libnetlink.h";
#UsrMerge
ln -s "%_sbindir/ip" "$b/sbin";
mkdir -p "$b/bin";
ln -sf "%_sbindir/ip" "$b/bin/ip";
#EndUsrMerge
rm "$b/%_sbindir/ifcfg";

mkdir -p "$b/%_docdir/%name";
# packaged in iproute2-doc:
rm -rf $b/%_docdir/%name/*
cp -an README* COPYING "$b/%_docdir/%name/"

%files
%defattr(-,root,root)
%dir %_docdir/%name
%_docdir/%name/README*
%_docdir/%name/COPYING
%_sbindir/*
#UsrMerge
/sbin/*
/bin/ip
#EndUsrMerge
%_mandir/man7/*
%_mandir/man8/*
%dir %_sysconfdir/iproute2
%config(noreplace) %_sysconfdir/iproute2/*
%_libdir/tc/
%_datadir/tc/

%files -n libnetlink-devel
%defattr(-,root,root)
%_includedir/*
%_mandir/man3/libnetlink*
%_libdir/lib*

%changelog
* Tue Sep  5 2017 mkubecek@suse.cz
- update upstream references:
  iplink-check-for-message-truncation-in-iplink_get.patch
  iplink-double-the-buffer-size-also-in-iplink_get.patch
* Fri Sep  1 2017 mkubecek@suse.cz
- iplink-check-for-message-truncation-in-iplink_get.patch:
  iplink-double-the-buffer-size-also-in-iplink_get.patch:
  Use larger buffer for link info with many VFs also in the other
  code path (bsc#1056261)
* Wed Aug 30 2017 mkubecek@suse.cz
- libnetlink-Double-the-dump-buffer-size.patch:
  Use larger buffer for dumps to allow link info from NICs with
  many VFs (bsc#1045399 bsc#1056261)
* Mon Jul 10 2017 mkubecek@suse.cz
- iproute-fix-documentation-for-ip-rule-scan-order.patch:
  iproute-fix-documentation-for-ip-rule-scan-order-2.patch:
  man-ip-rule.8-Further-clarify-how-to-interpret-prior.patch:
  man-ip-route.8-Mention-that-lower-metric-means-highe.patch:
  clarify the meaining of "priority" in ip-rule(8) and ip-route(8)
  manual pages (bsc#990635)
* Mon Jul 10 2017 mkubecek@suse.cz
- routel-fix-infinite-loop-in-line-parser.patch:
  fix command line parser in routel command (bsc#1034855)
* Fri Jul 29 2016 mkubecek@suse.cz
- revert the iproute2-doc merge; the dependencies of iproute2-doc
  prevent bootstrapping openSUSE distribution. (bsc#991185)
* Fri Jan 22 2016 mkubecek@suse.cz
- merge iproute2-doc.spec back into iproute2.spec
  iproute2-doc was separated into its own specfile to make rebuilds
  faster; this is not as important in SLE as it is in Factory and
  is not worth bothering with a multispec source package here
* Thu Jan 21 2016 mkubecek@suse.cz
- upgrade to upstream version 4.4 to match kernel version
  * implements fate#319924
- remove patches obsoleted by upgrade:
  Handle-netdev-group-for-veth-peer-too.patch:Patch-mainline (3.14)
  Revert-vxlan-remove-dstport-option.patch (3.14)
  bridge-fix-reporting-of-IPv6-addresses.patch (3.14)
  introduce-support-for-slave-info-data.patch (3.14)
  ip-fix-exit-code-for-addrlabel.patch (4.1)
  ip-fix-exit-code-for-rule-failures.patch (4.1)
  ip-return-correct-exit-code-on-route-failure.patch (4.1)
  ip-route-add-congestion-control-metric.patch (4.0)
  ip-support-of-usec-rtt-in-tcp_metrics.patch (3.17)
  iplink-add-support-for-bonding-netlink.patch (3.14)
  iplink-add-support-for-bonding-slave.patch (3.14)
  iplink_bond-fix-arp_all_targets-parameter-name-in-ou.patch (3.14)
  iplink_bond-fix-parameter-value-matching.patch (3.14)
  iplink_bond_slave-show-mii_status-only-once.patch (3.14)
  iproute-Fix-Netid-value-for-multi-families-output.patch (3.14)
  iproute2-finish-support-for-bonding-attributes.patch (3.14)
  update-kernel-headers-for-bonding-support.patch (3.14)
  update-kernel-headers-to-3.19-net-next.patch (4.0)
  update-kernel-headers-to-SLE12-SP1-Beta-1.patch (3.15)
  veth-Handle-flags-correctry.patch (3.14)
  veth-fix-uninitialized-arguments.patch (3.14)
- update non-upstream patches to version 4.4:
  adjust-installation-directories-for-SLE.patch
  avoid-unused-return-value-gcc-warnings.patch
- refresh remaining patches:
  add-explicit-typecast-to-avoid-gcc-warning.patch
  fix-build-with-D_FORTIFY_SOURCE-2.patch
  man-fix-documentation-references-in-manual-pages.patch
  use-sysconf-_SC_CLK_TCK-if-HZ-undefined.patch
- new non-upstream patches from Factory package:
  * xfrm-support-displaying-transformations-used-for-Mob.patch:
    support displaying xfrm transformations for Mobile IPv6
  * examples-fix-bashisms-in-example-script.patch:
    fix bashisms in example script declaring /bin/sh interpreter
* Mon Oct 19 2015 mkubecek@suse.cz
- ip-return-correct-exit-code-on-route-failure.patch:
  fix "ip route" exit code (bsc#949040)
- ip-fix-exit-code-for-rule-failures.patch:
  fix "ip rule" exit code (bsc#949040)
- ip-fix-exit-code-for-addrlabel.patch:
  fix "ip addrlabel" exit code (bsc#949040)
* Mon Oct 19 2015 mkubecek@suse.cz
- man-fix-documentation-references-in-manual-pages.patch:
  minor fix (README.lnstat is in iproute2, not iproute2-doc)
* Thu Oct  8 2015 mkubecek@suse.cz
- man-fix-documentation-references-in-manual-pages.patch:
  replace Debian specific documentation references by SUSE ones
  (bsc#949063)
* Wed Aug 12 2015 mkubecek@suse.cz
- update-kernel-headers-to-SLE12-SP1-Beta-1.patch:
  ip-support-of-usec-rtt-in-tcp_metrics.patch:
  display TCP RTT and RTT variance estimates with microsecond
  precision if kernel provides this information (bsc#937086)
- Revert-vxlan-remove-dstport-option.patch:
  add missing tags
* Tue Aug 11 2015 bpoirier@suse.com
- Revert-vxlan-remove-dstport-option.patch
  Add vxlan destination port option (fate#319084)
* Wed Jun 17 2015 mkubecek@suse.cz
- update-kernel-headers-to-3.19-net-next.patch:
  ip-route-add-congestion-control-metric.patch:
  add per-route congestion control support (fate#318553)
* Mon May 26 2014 mkubecek@suse.cz
- veth-fix-uninitialized-arguments.patch:
  fix crash in "ip link add type veth"
  (bnc#879865)
- Handle-netdev-group-for-veth-peer-too.patch:
  when adding veth device, group argument is parsed but ignored
  (bnc#879865)
- iproute-Fix-Netid-value-for-multi-families-output.patch
  when both -t and -u are used, ss reports UDP sockets as TCP
  (bnc#879865)
- bridge-fix-reporting-of-IPv6-addresses.patch
  fix output of IPv6 vxlan dst addresses in "bridge fdb show"
  (bnc#879865)
- veth-Handle-flags-correctry.patch
  fix handling of veth peer flags
  (bnc#879865)
* Fri Feb 28 2014 mkubecek@suse.cz
- update-kernel-headers-for-bonding-support.patch:
  iplink_bond-fix-arp_all_targets-parameter-name-in-ou.patch:
  iplink_bond-fix-parameter-value-matching.patch:
  update upstream references
- iplink-display-slave-information.patch:
  replaced by introduce-support-for-slave-info-data.patch
  (fate#316940)
- iplink_bond-add-support-for-displaying-bond-slave-at.patch:
  replaced by iplink-add-support-for-bonding-slave.patch
  (fate#316940)
- iplink_bond_slave-show-mii_status-only-once.patch:
  fix for bonding slave status being shown twice (fate#316940)
* Thu Feb 13 2014 mkubecek@suse.cz
- update-kernel-headers-for-bonding-support.patch:
  iplink-add-support-for-bonding-netlink.patch:
  iproute2-finish-support-for-bonding-attributes.patch:
  iplink_bond-fix-arp_all_targets-parameter-name-in-ou.patch:
  iplink_bond-fix-parameter-value-matching.patch:
  iplink-display-slave-information.patch:
  iplink_bond-add-support-for-displaying-bond-slave-at.patch:
  implement setting and displaying bonding (and bond slave)
  attributes in ip command (fate#316940)
* Mon Jan 20 2014 mkubecek@suse.cz
- restore SLE12 Alpha 1 version rewritten by pulling recent Factory
  changes
- update patches to git based versions:
  * iproute2-dirs.diff -> adjust-installation-directories-for-SLE.patch
  * iproute2-HZ.diff split into use-sysconf-_SC_CLK_TCK-if-HZ-undefined.patch
    and add-explicit-typecast-to-avoid-gcc-warning.patch
  * revert-pdf-creation.diff not needed on SLE12
- add SLE11 SP3 patches missing in upstream:
  * avoid-unused-return-value-gcc-warnings.patch:
    prevent GCC warnings considered errors by OBS
  * fix-build-with-D_FORTIFY_SOURCE-2.patch:
    fix build with -D_FORTIFY_SOUCE=2 to comply with TAHI testsuite
    (bnc#719537)
- iproute2.spec:
  remove conditionals not needed on SLE12
- fate#315437 implemented since upstream 3.11.0
* Mon Dec  9 2013 jengelh@inai.de
- Update to new upstream release 3.12
  * ip rule: add route suppression options
  * tc: support for the "fq" Fair Queue packet scheduler
  * tc: support 64-bit rate estimator statistics
  * GRE-over-IPv6 tunnel support
  * VXLAN IPV6 support
* Thu Sep 12 2013 jengelh@inai.de
- Update to new upstream release 3.11
  * Support for Linux 3.11
  * iptunnel: check SIT_ISATAP flag only for SIT tunnel
  * ss: show destination address for netlink sockets
  * ss: Get netlink sockets info via sock_diag
  * vxlan: Allow setting destination to unicast address
  * ss: add fastopen support
  * htb: report overhead attribute
  * ip: allow to specify mode for sit tunnels
  * ip: iplink_vlan: add 802.1ad support
  * iptuntap: allow creation of multi-queue tun/tap device
* Wed Sep 11 2013 werner@suse.de
- Make it build with latest TeXLive 2013
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 3.9.0
  * Support for managing the forwarding tables in Bridge and VXLAN.
- Remove 0001-build-resolve-compile-error-due-to-missing-include.patch
  (merged upstream)
- Signature verification for the package
* Mon Apr 15 2013 jengelh@inai.de
- Update to new upstream release 3.8.0
  * implement bridge mdb commands
  * add DOVE extensions
  * add `ip netns pids` and `ip netns identify`
  * tc netem: allow negative packet/cell overhead
  * support tunnels in `ip link type ipip|sit|ip6tnl`
- Add 0001-build-resolve-compile-error-due-to-missing-include.patch
* Thu Dec 13 2012 jengelh@inai.de
- Update to new upstream release 3.7.0
  * add support for tcp_metrics
  * iplink: Added support for the kernel IPoIB RTNL ops
  * ss: Get udp sockets info via sock-diag
  * tc: add canid ematch to ematch_map
  * vxlan support
* Tue Oct  9 2012 jengelh@inai.de
- Update to new upstream release 3.6.0
  * ss: report SK_MEMINFO_BACKLOG
  * tc: add ipset ematch
  * iplink: add support for num[tr]xqueues
  * iproute2: Add FDB print and update cmds for self and master
  * iproute: Add ability to save, restore and show the interfaces'
  addresses
  * iproute2: VTI support for ip link command
- Rename iproute2-libdir-1.diff to iproute2-dirs.diff, as it does
  more than just changing LIBDIR.
- Add revert-pdf-creation.diff, as the new PDF creation commands
  do not want to work with openSUSE 12.2 and before.
* Tue Sep 18 2012 werner@suse.de
- Make it build even without pdflatex, use latex+dvips, beside this
  iproute2-pdflatex.diff was documented, see my last entry from
  Jul 30 14:33:58 UTC 2012.
* Mon Sep 17 2012 idonmez@suse.com
- Add BuildRequires on texlive-dvips for openSUSE > 12.2 to fix
  Factory builds.
* Sat Sep  8 2012 jengelh@inai.de
- Update to new upstream release 3.5.1
  * ss: Report MSS from internal TCP information
  * ip: allow IPv6 addresses for l2tp local and remote parameters
  * tc: Support for tc_codel - Controlled Delay AQM
  * tc: Support for fq_codel - Fair Queue Codel AQM
  * tc-netem: Add support for ECN packet marking
- Remove undocumented iproute2-pdflatex.diff which breaks the
  build since using the iproute2-3.5.1 tarball
* Mon Jul 30 2012 werner@suse.de
- Make it build with modern pdflatex and TeXLive 2012 ... for this
  also sgmltools has to know about correct babel style usage
* Thu May 24 2012 jengelh@inai.de
- Update to new upstream release 3.4.0
  * for kernel 3.4
  * ss: use new INET_DIAG_SKMEMINFO option to get more memory
  information for tcp socket
  * ip: add ability to set link state
* Sat Mar 31 2012 bili@suse.com
- Distribute COPYING file for rpm(bnc#745225).
* Fri Mar 30 2012 jengelh@medozas.de
- Update to new upstream release 3.3.0
  * This release updates qdisc parameters in sfq and red, adds Netem
  extensions for shaping and for loss models, adds lots of manual
  page corrections, adds the QFQ scheduler and the LLDP-to-ethernet
  type table (along with support for processless network namespaces
  and L2TPv3 plus L2TP tunneling), improves RED options, and adds
  assorted bugfixes.
* Thu Mar  8 2012 rschweikert@suse.com
- Place ip binary in /usr tree (UsrMerge project)
- Fix permissions to eliminate rpmlint errors
* Sat Jan 14 2012 jengelh@medozas.de
- Update to new upstream release 3.2.0
  * L2TPv3 support
  * netem additions for loss models, improved RED options
* Sat Dec 31 2011 jengelh@medozas.de
- Update to new upstream release 3.1.0
  * ip: Add processless network namespace support
  * tc: Add QFQ scheduler
  * ss: display closed UDP sockets on `ss -ul`
  * ss: report ecnseen
  * Add L2TP support
* Fri Oct 21 2011 jengelh@medozas.de
- Clarify license for iproute2.spec (bnc#720282)
* Sat Sep 24 2011 jengelh@medozas.de
- Add patch iproute2-xt-detect.diff to address shipped Makefiles'
  failure to use pkg-config to locate libxtables, and thus
  reenable m_xt
* Fri Jul  8 2011 jengelh@medozas.de
- Update to new upstream release 2.6.39
  * support device group semantics
  * support listing devices by group
  * parse flag XFRM_POLICY_ICMP
  * CHOKe scheduler
  * macvlan/macvtap: support 'passthru' mode
  * tc: SFB flow scheduler
  * tc add mqprio qdisc support
  * xfrm security context support
  * allow to specify truncation bits on auth algo
  * fix unit conversion of rtt/rttvar/rto_min
  * support IFLA_TXQLEN in ip link command
- Remove iproute2-pdfdoc.diff: merged upstream
- Remove iproute2-memleak.diff: merged upstream
* Tue May 31 2011 jengelh@medozas.de
- Correct installation path of tc modules
- Restore symbol lookup in m_xt.so (bnc#679172)
- Add patches to make m_xt build with libxtables6
- Restore m_xt's module lookup (bnc#660554)
- Run spec-beautifier
* Mon May 30 2011 jengelh@medozas.de
- Disable building m_xt.so which has not been updated for
  iptables 1.4.11
* Wed Mar 23 2011 bphilips@novell.com
  Remove unneeded patches:
  * iproute2-warnings.diff bnc#34714
  Warnings no longer exist
  * iproute2-iptunnel-fclose.diff
  Process is dying no need to close file pointers
  * iproute2-ss-pclose.diff
  Process is dying no need to close file pointers
  * iproute2-flushcheckuid.diff
  Fixed upstream
  * iproute2-skbedit-memset.diff
  Fixed upstream 46a6573259f46f86eb0048a2c805b24ff4183fa6
* Tue Mar 22 2011 ms@suse.de
- Update to 2.6.38, fix for options process with ipt (bnc #679172)
- tidy up the package, spec file names, patch names, etc
* Wed Jan 12 2011 mt@suse.de
- Adopted ip route rtt,rttvar,rto_min metrics time unit to
  milliseconds as required by recent kernels (bnc#659746).
* Tue Jan 11 2011 jengelh@medozas.de
- Update to iproute2-2.6.37
  * Support for iptables >= 1.4.9
  * Support for GRE in XFRM
  * tc f_flow now knows rxhash
  * Support for macvtap "mode" parameter
  * tc ACT_CSUM support
  * added `ip route save` and `ip route restore` commands
- Spec file updates
  * Remove pointless AutoReqProv:on (that's the default)
  * Enable tc's m_xt
* Fri Dec  3 2010 ms@suse.de
- removed the fragtimeout patch because it breaks the rto_min
  setup. The fragtimeout patch also requires a kernel side
  modification which we don't ship since SLES9 (bnc #656667)
* Mon Nov 15 2010 jengelh@medozas.de
- Split documentation into its own subpackage, reducing the size
  of the main package by ~500K
* Wed Nov  3 2010 jengelh@medozas.de
- Update to iproute2-2.6.35+git9 for obtaining
  Linux 2.6.36-introduced features (no iproute2-2.6.36 tag yet)
  * Added RTA_MARK support (e.g. `ip route get ::1 mark 2`)
  * 64-bit interface statistics
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.35
  * Added support for multicast iprules
  * Speed up `ss -p`
  * Update ARP header type table
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.34
  * Fix build issues with flex 2.5
  * Detect 6rd tunnel scope
  * Added `ip tuntap` support (this practically obsoletes the
  "tunctl" package)
  * Added support for XFRM/SA by fwmark
  * Added initrwnd
- 2 patches integrated, thus dropped
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.33
  * Added 6rd support
  * Added macvlan options for bridge mode
  * Added support to mark packets in skbedit
  * Added oif classification support in iprule
* Tue Nov  2 2010 jengelh@medozas.de
- Update to iproute2-2.6.31
  * Dropped equalize support
  * Fixed segfault when using garbage lladdr
  * Added new m_xt module for iptables-1.4.5
  * Added support for CAN
  * Allow ISATAP with stateless autoconfiguration
  * Added support for cgroup
  * Added support for monitoring neigh table activities
- 3 patches integrated, thus dropped
* Tue Feb 23 2010 jengelh@medozas.de
- add a patch to avoid tun tunnels being shown as "link/65534"
* Sat Dec 19 2009 jengelh@medozas.de
- enable parallel build
* Wed Nov 11 2009 ms@suse.de
- check effective UID instead of real UID in the flush
  permissions coding (bnc #554419)
* Fri Oct  9 2009 ms@suse.de
- added missing fclose to ss utility (bnc #543986)
* Wed Sep 16 2009 ms@suse.de
- fixed memory leak in read_igmp() function ip/ipmaddr.c (bnc #538996)
* Thu Sep 10 2009 ms@suse.de
- added support for monitoring neighbour tables (bnc #537906)
- added support for displaying type labels (bnc #537906)
* Fri Aug 28 2009 ms@suse.de
- added missing pclose (bnc #534912)
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Aug 12 2009 adrian@suse.de
- update to version 2.6.29-1
  * Support for lxc
* Tue Jul 28 2009 ms@suse.de
- make sure do_tunnels_list proc file descriptor will be
  closed after use or on proc read error (bnc #525834)
* Thu Feb 19 2009 ms@suse.de
- fixed ss utility to display inet6 addresses if requested
  with -6 or -f inet6 (bnc #473156)
* Tue Jan 27 2009 ms@suse.de
- fixed a bug in which the memory for the tc_skbedit struct was
  being used uninitialized to 0.  This patch corrects the issue
  by using a memset to 0 out the memory of the
  structure (bnc #438950)
* Thu Dec 11 2008 agruen@suse.de
- Change max length of the MAC address from 16 bytes to 32 bytes
  to accommodate infiniband (bnc#445014).
* Mon Oct 13 2008 ms@suse.de
- fixed compiler warnings (bnc #434714)
* Thu Sep 18 2008 hare@suse.de
- Add skbedit support for FCoE (FATE#303914)
- Add multiqueue support for FCoE (FATE#303914)
- Rename libnl to libnetlink-devel
- Fix IPPROTO_DCCP redefine
- rpmlint fixes
* Mon Jul 14 2008 ms@suse.de
- update to version 2.6.25
  * Fix off by one in nested attribute management.
  * netem potential dist table overflow
  * rto_min value display overflow
  * Overhead calculation is now done in the kernel.
  * libnetlink: don't spin forever on receive error
  * Protocol field on tc_filter is required by the kernel, provide it
  * Add missing prefix bit length for addrlabel
  * Do not strip binaries with `install`
  * In police, fix uninitialized "overhead" variable.
  * lots of documentation fixes
* Fri Jul 11 2008 ms@suse.de
- fixed RTM_NEWLINK check for older kernels (bnc #407954)
* Mon Jun 30 2008 ms@suse.de
- fixed 'tc qdisc' segmentation fault (bnc #404755)
* Thu May  8 2008 ms@suse.de
- compile libnetlink with -fPIC (bnc #388021)
* Wed Apr 16 2008 schwab@suse.de
- Don't strip binaries.
* Thu Oct 25 2007 ms@suse.de
- update to version 2.6.23, fixed (#336488)
  Reason for update:
  * The macvlan module, which got added to the kernel in version
    2.6.23, needs the new "ip link add" feature
  These patches add a rewritten version of Ben's macvlan driver, which
  allows to create virtual ethernet devices. The underlying device is
  put in promiscous mode and packets are demuxed based on MAC address.
  It behaves similar to bridge devices in that packets are visible on
  the real device before delivery to the macvlan driver. The driver
  supports all features of the underlying device except VLAN
  acceleration, this is currently very hard to support. I might look
  into this in the future.
  The main downside of this driver is that it adds another hook in
  netif_receive_skb, unfortunately that is unavoidable. When not
  compiled in the hook vanishes of course.
  Usage is simple:
    ip link add link eth0 type macvlan
  Will create a macvlan0 device with a random MAC address on top of
  eth0. No iproute patches are required.
* Tue Oct 16 2007 jdelvare@suse.de
- libnetlink.3 is now part of the upstream package, no need to
  include our own copy.
* Wed Jul 11 2007 ms@suse.de
- update to version 2.6.22, fixed (#288551)
  * Kim Woelders <kim@woelders.dk>, various useful fixups: compilation
  with old kernels, cross-compiling, "all" == "any" in prefix spec.
  * Collected from my disk, cleaned and packed to directory iproute2/misc/
    several utilities: ss, nstat, ifstat, rtacct, arpd and module tcp_diag.
    Writing some docs. me.
  * prepared patchlet for pidentd to use tcp_diag.
  * David Miller: 64bit (and even worse 64bit kernel/32 bit user :-) fixes
    to above. tcp_diag is merged to main tree.
  * Alexandr D. Kanevskiy <kad@blackcatlinux.com>: various flaws in ss
  * Alexandr D. Kanevskiy <kad@blackcatlinux.com>: oops, more aggressive caching
    of names opened old bugs: ip started to print garbage in some places.
  * Robert Olsson, rt_cache_stat. Renamed to rtstat.
  * An old bug in "ip maddr ls": reduntant empty lines in output.
    Seeing this crap for ages but lucky match of desire/ability to repair
    and a huff about this happened only today. :-)
  * "Mr. James W. Laferriere" <babydr@baby-dragons.com>
    doc: option to produce ps output for non-a4 and not only 2 pages/sheet.
  * Jamal's patch for ingres qdisc.
  * Bernd Eckenfels <ecki@lina.inka.de>: deleted orphaned bogus #include
    in include/utils.h.
  * Julian Anastasov <ja@ssi.bg>: uninitialized fields in nexthop
    producing funny "dead" nexthops in multipath routes.
    Stupid me, look at the first line in [010803]... Was it difficult to guess
    this that time? People blame for several months. :-)
    Special thanks to bert hubert <ahu@ds9a.nl> who raised the issue in netdev.
    Thanks and apologies to Terry Schmidt <terry@nycwireless.net>,
    Ruben Puettmann <ruben.puettmann@freenet-ag.de>,
    Mark Ivens <mivens@clara.net>.
  * willy tarreau <wtarreau@yahoo.fr>: "make install" target.
  * Tunable limit for sch_sfq. Patch to kernel activating this
    is about to be submitted. Reminded by Adi Nugroho <Adi@iNterNUX.co.id>
* Fri Apr 20 2007 aj@suse.de
- Use texlive for building.
* Mon Apr  2 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Thu Feb  8 2007 ms@suse.de
- fixed array size of name string in iptables.h (#243281)
  array of size IPT_FUNCTION_MAXNAMELEN - 1 is referenced
  at element IPT_FUNCTION_MAXNAMELEN - 1 which is outside the
  array bounds
* Mon Jan 29 2007 ms@suse.de
- fixed wrong IPT_LIB_DIR value and replaced the code by a
  dynamic check for the /usr/%%lib/iptables directory (#238886)
* Tue Nov  7 2006 ro@suse.de
- fix permissions for manpage
* Thu Jul 20 2006 ms@suse.de
- replaced static HZ define to dynamic:
  [#]ifndef HZ
  [#]define HZ sysconf(_SC_CLK_TCK)
  [#]endif
* Thu May 25 2006 schwab@suse.de
- Fix crash while resolving addresses.
* Mon Apr  3 2006 hvogel@suse.de
- fix flex input file to use uppercase STR to avoid conflicts.
  This prevented tc from being build [#162931]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 mrueckert@suse.de
- update to version 2.6.15-060110
* Tue Nov  8 2005 mmj@suse.de
- update to version 051107
* Sun Oct 23 2005 ro@suse.de
- fix filelist for libnlink
* Thu Oct 20 2005 mmj@suse.de
- update to version 051007
- fix buffer overflow in iproute.c [#129415] (thanks Richard, Marcus)
- don't strip stuff
* Wed Aug 17 2005 cthiel@suse.de
- update to version 050816 [#105087]
* Sat Aug  6 2005 dmueller@suse.de
- add /bin/ip symlink (#102513)
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Mon May  9 2005 mmj@suse.de
- Update to 2.6.11-050330
* Thu Feb 10 2005 ro@suse.de
- remove dropped tetex subpackages from nfb
* Fri Feb  4 2005 mmj@suse.de
- Update to 2.6.10-ss050124
* Tue Dec  7 2004 mmj@suse.de
- Don't trust that the kernel and do our own family check [#48600]
* Sun Oct 24 2004 mmj@suse.de
- Clean up spec file a bit
- Update to new snapshot including even more of our patches
* Tue Oct 12 2004 mmj@suse.de
- Update to 2.6.9 including some of our patches
* Tue Aug 17 2004 mmj@suse.de
- Make ip print correct type when printing stats [#42589]
* Wed Apr 21 2004 mmj@suse.de
- Fix bufferoverflow in nstat [#39179]
* Fri Apr 16 2004 kukuk@suse.de
- Fix compiling with 2.6.5 kernel headers
- Remove backup files
* Wed Apr 14 2004 mmj@suse.de
- Don't remove buildroot before install
* Wed Mar 17 2004 mmj@suse.de
- No executables below /usr/include [#36342]
* Wed Mar 10 2004 mmj@suse.de
- Olaf Kirch fixed the kernel, so remove the fix for [#35288]
* Wed Mar  3 2004 ak@suse.de
- Fix hang in ip addr flush (#35288)
* Wed Jan  7 2004 mmj@suse.de
- ifstat should store it's history in /var/tmp not /tmp
* Mon Nov 10 2003 mmj@suse.de
- Add more man-pages [#32981]
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
* Mon Aug 11 2003 mmj@suse.de
- Add all the pdf documentation [#28637]
* Thu Jun 12 2003 kukuk@suse.de
- Fix filelist
* Wed Jun  4 2003 kukuk@suse.de
- Don't use include-glibc directory
- Fix arpd to compile with db4
* Tue May 13 2003 mmj@suse.de
- Remove files we don't package
* Mon May 12 2003 mmj@suse.de
- Add glib-include from newer iputils, and change a kernel-include
  to make it build
* Tue Feb 11 2003 ug@suse.de
- patch for HTB support applied since 2.4.20 supports it
* Fri Feb  7 2003 mmj@suse.de
- Make the man tar-ball not contain gzipped man-pages, it's already
  compressed once.
- Apply patch from Andi Kleen for fragtimeout functionality
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <sp> to <opensp>
* Sun Oct 20 2002 mmj@suse.de
- Add manpages, thanks to ASPLinux [#21115]
* Wed Aug 21 2002 mmj@suse.de
- Added a patch to exit when regular user tries to flush routes or
  addresses. [#16000]
* Sun Aug 18 2002 ro@suse.de
- added ghostscript-x11-packages to neededforbuild (for gs)
* Mon Apr  8 2002 postadal@suse.cz
- updated to ss020116
  * added several utilities several utilities: ss, nstat, ifstat,
    rtacct, arpd and module tcp_diag
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 31 2002 ro@suse.de
- added libgimpprint to neededforbuild
* Tue Jan 29 2002 vinil@suse.cz
- /usr/lib -> %%_libdir
* Sun Jan 20 2002 vinil@suse.cz
- new version ss010824
- spec file cleanup
* Mon Nov 19 2001 bjacke@suse.de
- move ip to /sbin
- add iproute2 config files to /etc/
* Wed Oct 10 2001 stepan@suse.de
- fix compilation on ia64
* Tue Sep 18 2001 pthomas@suse.de
- Correct spelling in libnetlink.3
- Add both German and English descriptions for libnlink
* Mon Aug 27 2001 kukuk@suse.de
- Fix compiling on SPARC
* Tue Aug 21 2001 vinil@suse.cz
- new version ss010803
- get rid of kernel 2.2 patches
* Thu Jul 26 2001 kukuk@suse.de
- add glib to needed for build
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_fonts> to <ghostscript-fonts-std>
- changed neededforbuild <gs_lib> to <ghostscript-library>
- changed neededforbuild <gs_x11> to <ghostscript-x11>
* Tue Jun 26 2001 ro@suse.de
- ETH_P_ECHO is apparently no longer defined
* Thu Mar  8 2001 uli@suse.de
- added xshared to neededforbuild
* Mon Mar  5 2001 kukuk@suse.de
- Remove bogus check for kernel header
* Fri Dec  1 2000 kukuk@suse.de
- Update to iproute2-2.2.4-now-ss001007 to fix compile problems
  with new kernel and glibc
* Mon Aug 28 2000 ak@suse.de
- fix permissions
- fix advmss/mtu confusion between 2.2 and 2.4 (advmss now works with 2.2
  kernels and is always enabled)
- add a new subrpm for libnetlink
- add libnetlink man page
* Tue Jul  4 2000 mha@suse.de
- new version (2.2.4-now-ss000305)
- new README.SuSE
- use ps2pdf instead of pdflatex, because the latter produces
  unusable pdf files for some reason
* Thu Jun  1 2000 vinil@suse.cz
- documentation enhancement
* Fri May 26 2000 vinil@suse.cz
- new version (ss000225)
- buildroot added
- sorted in group
* Thu Feb 17 2000 mha@suse.de
- new version (ss991023)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul 22 1999 mha@suse.de
- new version
- renamed package iproute->iproute2, because that's how the author
  calls it
* Tue Jul 13 1999 ro@suse.de
- added psutils to neededforbuild
* Sun Jul 11 1999 mha@suse.de
- new package: iproute (tools for using the advanced routing options
    in kernel 2.2)
